==> optaplanner-distribution-7.0.0.Final.zip: optaplanner-distribution-7.0.0.Final/examples/sources/src/test/java/org/optaplanner/examples/coachshuttlegathering/app/CoachShuttleGatheringPerformanceTest.java <==
/*
 * Copyright 2015 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.optaplanner.examples.coachshuttlegathering.app;

import java.io.File;

import org.junit.Test;
import org.optaplanner.core.config.solver.EnvironmentMode;
import org.optaplanner.examples.coachshuttlegathering.persistence.CoachShuttleGatheringDao;
import org.optaplanner.examples.common.app.SolverPerformanceTest;
import org.optaplanner.examples.common.persistence.SolutionDao;

public class CoachShuttleGatheringPerformanceTest extends SolverPerformanceTest {

    @Override
    protected String createSolverConfigResource() {
        return CoachShuttleGatheringApp.SOLVER_CONFIG;
    }

    @Override
    protected SolutionDao createSolutionDao() {
        return new CoachShuttleGatheringDao();
    }

    // ************************************************************************
    // Tests
    // ************************************************************************

    @Test(timeout = 600000)
    public void solveDemo01() {
        File unsolvedDataFile = new File("data/coachshuttlegathering/unsolved/demo01.xml");
        runSpeedTest(unsolvedDataFile, "0hard/-389030soft");
    }

    @Test(timeout = 600000)
    public void solveDemo01FastAssert() {
        File unsolvedDataFile = new File("data/coachshuttlegathering/unsolved/demo01.xml");
        runSpeedTest(unsolvedDataFile, "0hard/-389030soft", EnvironmentMode.FAST_ASSERT);
    }

}

==> optaplanner-distribution-7.31.0.Final.zip: optaplanner-distribution-7.31.0.Final/examples/sources/src/test/java/org/optaplanner/examples/coachshuttlegathering/app/CoachShuttleGatheringPerformanceTest.java <==
/*
 * Copyright 2015 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.optaplanner.examples.coachshuttlegathering.app;

import java.io.File;

import org.junit.Test;
import org.optaplanner.core.config.solver.EnvironmentMode;
import org.optaplanner.examples.coachshuttlegathering.domain.CoachShuttleGatheringSolution;
import org.optaplanner.examples.common.app.SolverPerformanceTest;

public class CoachShuttleGatheringPerformanceTest extends SolverPerformanceTest<CoachShuttleGatheringSolution> {

    public CoachShuttleGatheringPerformanceTest(String moveThreadCount) {
        super(moveThreadCount);
    }

    @Override
    protected CoachShuttleGatheringApp createCommonApp() {
        return new CoachShuttleGatheringApp();
    }

    // ************************************************************************
    // Tests
    // ************************************************************************

    @Test(timeout = 600000)
    public void solveDemo01() {
        File unsolvedDataFile = new File("data/coachshuttlegathering/unsolved/demo01.xml");
        runSpeedTest(unsolvedDataFile, "0hard/-389030soft");
    }

    @Test(timeout = 600000)
    public void solveDemo01FastAssert() {
        File unsolvedDataFile = new File("data/coachshuttlegathering/unsolved/demo01.xml");
        runSpeedTest(unsolvedDataFile, "0hard/-389030soft", EnvironmentMode.FAST_ASSERT);
    }

}
